#nvpl_tensor-config.cmake
#
# Imported interface targets provided:
#  * nvpl::tensor - alias to shared library target
#
# Output variables set:
#  * nvpl_tensor_VERSION - Version of installed package
#  * nvpl_tensor_INCLUDE_DIR - Location of nvpl_tensor headers
#  * nvpl_tensor_LIBRARY_DIR - Location of nvpl_tensor libraries


set(nvpl_tensor_VERSION "0.3.0")
# build: 1660



## Dependencies
include(CMakeFindDependencyMacro)
if(NOT nvpl_blas_FOUND)
    find_dependency(nvpl_blas REQUIRED)
endif()

## Find header and lib directories via known header and lib names
set(_nvpl_tensor_search_header_name nvpl_tensor.h)
set(_nvpl_tensor_search_lib_name libnvpl_tensor.so)
get_filename_component(_nvpl_tensor_search_prefix "${CMAKE_CURRENT_LIST_DIR}/../../" ABSOLUTE)

find_path(nvpl_tensor_INCLUDE_DIR
          NAMES ${_nvpl_tensor_search_header_name}
          PATHS ${_nvpl_tensor_search_prefix}
          PATH_SUFFIXES
            ../include
            ../../include # Debian/Ubuntu aarch64
          NO_DEFAULT_PATH
          NO_CACHE) # Set cache variable after path normalization

find_path(nvpl_tensor_LIBRARY_DIR
          NAMES ${_nvpl_tensor_search_lib_name}
          PATHS ${_nvpl_tensor_search_prefix}
          PATH_SUFFIXES lib lib64
          DOC "Location of nvpl_tensor libraries"
          NO_DEFAULT_PATH)

# Check headers and library directories are found
if(NOT EXISTS "${nvpl_tensor_INCLUDE_DIR}")
    message(FATAL_ERROR "Header directory containing file ${_nvpl_tensor_search_header_name} was not found relative to ${CMAKE_CURRENT_LIST_DIR}!")
endif()
if(NOT EXISTS "${nvpl_tensor_LIBRARY_DIR}")
    message(FATAL_ERROR "Library directory containing file ${_nvpl_tensor_search_lib_name} was not found relative to ${CMAKE_CURRENT_LIST_DIR}!")
endif()

# Normalize nvpl_tensor_INCLUDE_DIR and set cache variable
get_filename_component(nvpl_tensor_INCLUDE_DIR "${nvpl_tensor_INCLUDE_DIR}" ABSOLUTE)
set(nvpl_tensor_INCLUDE_DIR ${nvpl_tensor_INCLUDE_DIR} CACHE STRING "Location of nvpl_tensor headers")

unset(_nvpl_tensor_search_header_name)
unset(_nvpl_tensor_search_lib_name)
unset(_nvpl_tensor_search_prefix)

## Targets
if(NOT TARGET nvpl_tensor)
    include("${CMAKE_CURRENT_LIST_DIR}/nvpl_tensor-targets.cmake")
endif()

if(NOT TARGET nvpl::tensor)
    set_target_properties(nvpl_tensor PROPERTIES IMPORTED_GLOBAL 1)
    add_library(nvpl::tensor ALIAS nvpl_tensor)
endif()

check_required_components(nvpl_tensor)
if(NOT ${CMAKE_FIND_PACKAGE_NAME}_FIND_QUIETLY)
    message(STATUS "Found nvpl_tensor: (Version:${nvpl_tensor_VERSION}
                       CMakePackageDir:${CMAKE_CURRENT_LIST_DIR}
                       IncludeDir:${nvpl_tensor_INCLUDE_DIR}
                       LibraryDir:${nvpl_tensor_LIBRARY_DIR})")
endif()
